{#
    This file is part of Invenio.
    Copyright (C) 2015-2022 CERN.
  
    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.
#}
{% extends "invenio_pages/default.html" %}

{% block content %}{{ page.content|render_string|safe }}{% endblock content %}
