{#
  This file is part of Invenio.
  Copyright (C) 2015-2022 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{% extends config.PAGES_BASE_TEMPLATE %}

{% set title = page.title %}

{% block page_body %}
<div class="container">
  <div class="row">
    <div class="col-xs-12">
    {% block content %}{{ page.content|safe }}{% endblock %}
    </div>
  </div>
</div>
{% endblock %}
